# Transfer Function to State Space Conversion Comparison

This report compares the poles of state-space realizations obtained using different implementations:
1. Our implementation
2. SLYCOT implementation 
3. MATLAB implementation

## Comparison Table of Poles

| Numerator | Denominator | Our Implementation | SLYCOT Implementation | MATLAB Implementation |
|-----------|-------------|-------------------|----------------------|----------------------|
| [[[1, 1]]] | [[[1, 3, 2]]] | -2.0 + 0.0j<br>-1.0 + 0.0j | -2.0 + 0.0j | -2.0 + 0.0i<br>-1.0 + 0.0i |
| [[[0.0, 0.0, 1.0], [1.0, 0.0, 0.0]],<br>[[3.0, -1.0, 1.0], [0.0, 1.0, 0.0]],<br>[[0.0, 0.0, 1.0], [0.0, 2.0, 0.0]]] | [[[1.0, 0.4, 3.0], [1.0, 1.0, 0.0]],<br>[[1.0, 0.4, 3.0], [1.0, 1.0, 0.0]],<br>[[1.0, 0.4, 3.0], [1.0, 1.0, 0.0]]] | 0. +0.j<br>-0.2+1.72046505j<br>-0.2-1.72046505j<br>-1. +0.j | -0.2+1.72046505j<br>-0.2-1.72046505j<br>-0.2+1.72046505j<br>-0.2-1.72046505j<br>-0.2+1.72046505j<br>-0.2-1.72046505j<br>-1. +0.j<br>-1. +0.j<br>-1. +0.j  | -0.2 + 1.7205i<br>-0.2 - 1.7205i<br>0.0 + 0.0i<br>-1.0 + 0.0i |
| [[[1.0, 6.0, 12.0, 7.0], [0.0, 1.0, 4.0, 3.0]],<br>[[0.0, 0.0, 1.0, 1.0], [1.0, 8.0, 20.0, 15.0]]] | [[[1.0, 6.0, 11.0, 6.0], [1.0, 6.0, 11.0, 6.0]],<br>[[1.0, 6.0, 11.0, 6.0], [1.0, 6.0, 11.0, 6.0]]] | -3.0 + 0.0j<br>-2.0 + 0.0j<br>-1.0 + 0.0j | -3.0 + 0.0j<br>-2.0 + 0.0j<br>-1.0 + 0.0j<br>-2.0 + 0.0j<br>-2.0 + 0.0j<br>-3.0 + 0.0j<br>-2.0 + 0.0j | -3.0 + 0.0i<br>-2.0 + 0.0i<br>-1.0 + 0.0i<br>-3.0 + 0.0i<br>-2.0 + 0.0i<br>-1.0 + 0.0i |


## Comparison Table of Transmission Zeros

| Numerator | Denominator | Our Implementation | SLYCOT Implementation | MATLAB Implementation |
|-----------|-------------|-------------------|----------------------|----------------------|
| [[[1, 1]]] | [[[1, 3, 2]]] | -1.0 + 0.0j | [] | -1.0 + 0.0i |
| [[[0.0, 0.0, 1.0], [1.0, 0.0, 0.0]],<br>[[3.0, -1.0, 1.0], [0.0, 1.0, 0.0]],<br>[[0.0, 0.0, 1.0], [0.0, 2.0, 0.0]]] | [[[1.0, 0.4, 3.0], [1.0, 1.0, 0.0]],<br>[[1.0, 0.4, 3.0], [1.0, 1.0, 0.0]],<br>[[1.0, 0.4, 3.0], [1.0, 1.0, 0.0]]] | [] | -2.87e-17 + 0.0j<br>0.167 + 0.553j<br>0.167 - 0.553j | -3.1991e-17 + 0.0i |
| [[[1.0, 6.0, 12.0, 7.0], [0.0, 1.0, 4.0, 3.0]],<br>[[0.0, 0.0, 1.0, 1.0], [1.0, 8.0, 20.0, 15.0]]] | [[[1.0, 6.0, 11.0, 6.0], [1.0, 6.0, 11.0, 6.0]],<br>[[1.0, 6.0, 11.0, 6.0], [1.0, 6.0, 11.0, 6.0]]] | -1.0 + 0.0j<br>-0.333 + 0.0j | -3.618 + 0.0j<br>-2.5 - 0.866j<br>-2.5 + 0.866j<br>-1.382 + 0.0j | -3.2328 + 0.7926i<br>-3.2328 - 0.7926i<br>-1.5344 + 0.0000i<br>-2.0000 + 0.0000i<br>-3.0000 + 0.0000i<br>-1.0000 + 0.0000i |
